lexicor library

Lexicor — WordNet for Dart

Public re-exports for the package;

Classes

Concept
Represents a semantic concept (WordNet synset).
Lexicor
The public entry point for the Lexicor WordNet engine.
LookupResult
Result wrapper returned by Lexicor.lookup.
RelatedWord
Represents a word related to a specific concept.
RelationResult
Wrapper for related-word results for a concept.

Enums

DomainCategory
Topical or semantic domains for concepts.
RelationType
Types of lexical and semantic relations between concepts and words.
SpeechPart
Part-of-speech used by Lexicor.
StorageMode
Defines how the Lexicor database is loaded and accessed.