RelationResult class
Wrapper for related-word results for a concept.
- Annotations
-
- @immutable
Constructors
-
RelationResult(List<
RelatedWord> items) -
Create a new RelationResult.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Returns true if no related words were found.
no setter
- isNotEmpty → bool
-
Returns true if one or more related words were found.
no setter
-
items
→ List<
RelatedWord> -
The returned related words (semantic + lexical).
final
-
lexical
→ List<
RelatedWord> -
Filters the results to only lexical relations (Word-to-Word).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
semantic
→ List<
RelatedWord> -
Filters the results to only semantic relations (Concept-to-Concept).
no setter
Methods
-
byType(
RelationType type) → List< RelatedWord> - Returns a list filtered by a specific relationship type.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
unique(
) → List< RelatedWord> - Remove duplicate pairs and preserve order.
-
words(
{bool distinct = true}) → List< String> - Extract distinct words preserving insertion order.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited